//
//  QHVCCommonCoreEntry.h
//  QHVCCommonKit
//
//  Created by deng on 2017/9/8.
//  Copyright © 2017年 qihoo 360. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "QHVCTypes.h"
#import "QHVCCore_entryS.h"

typedef NS_ENUM(NSInteger, QHVCAuthStatus)
{
    QHVCAuthStatus_OK = 1,                //鉴权成功
    QHVCAuthStatus_FAILED = -11001,       //鉴权未通过（鉴权失败）
    QHVCAuthStatus_NOT_INVOKED = -11002   //未调用鉴权接口
};

@interface QHVCCommonCoreEntry : NSObject

/**
 * 通知SDK app启动
 * 必须在app启动的第一时间调用，且在整个app生命周期只调用一次
 * @param businessId 业务ID
 * @param appVer 端版本
 * @param deviceId 机器id
 * @param model 型号
 * @param ops 可选参数,例如：@{@"product":@"intValue(QHVCCommonProduct)"}
 */
+ (void)coreOnAppStart:(NSString *)businessId
                appVer:(NSString *)appVer
              deviceId:(NSString *)deviceId
                 model:(NSString *)model
        optionalParams:(NSDictionary *)ops;

/**
 * SDK鉴权
 * 必须在coreOnAppStart之后调用，建议取到token之后第一时间调用
 * @param callback 回调
 * @param token 需要业务在服务端按照指定的规则生成，客户端从业务服务器上拿取。计算token时，需要appId(即原来的bid),  accessKey, secretKey，需从视频云官网获取
 * authTime: unix时间戳（10位），需要和计算token时的值一致
 * randNum: 随机正整数。需要和计算token时的值一致
 * callback：鉴权结果回调
 */
+ (void)validityCheck:(NSString *)token randNum:(NSString *)randNum authTime:(NSString *)authTime callback:(void (^)(QHVCAuthStatus ret, NSString *detail))callback;

/**
 * 网络变化时通知传输层进行相应处理
 * @param type 网络变化类型
 */
+ (void)coreNetworkChange:(QHVCNetworkChangeType)type;

+ (void)initLua:(NSString *)libPath;
+ (void)initFastUdx:(NSString *)libPath;

/**
 *  @功能 获取基础库sdk版本号
 *  @返回值 sdk版本号（e.g. 2.0.0.0）
 */
+ (NSString *)sdkVersion;

@end
